Index: main/waeup.aaue/trunk/src/waeup/aaue/interfaces.py
===================================================================
--- main/waeup.aaue/trunk/src/waeup/aaue/interfaces.py	(revision 15178)
+++ main/waeup.aaue/trunk/src/waeup/aaue/interfaces.py	(revision 15180)
@@ -236,4 +236,16 @@
         )
 
+    sports_fee = schema.Float(
+        title = _(u'Sports Development Fee'),
+        default = 0.0,
+        required = True,
+        )
+
+    library_fee = schema.Float(
+        title = _(u'Library Development Fee'),
+        default = 0.0,
+        required = True,
+        )
+
     coursereg_deadline = schema.Datetime(
         title = _(u'FT Course Reg. Deadline'),
Index: main/waeup.aaue/trunk/src/waeup/aaue/interswitch/browser.py
===================================================================
--- main/waeup.aaue/trunk/src/waeup/aaue/interswitch/browser.py	(revision 15178)
+++ main/waeup.aaue/trunk/src/waeup/aaue/interswitch/browser.py	(revision 15180)
@@ -240,4 +240,8 @@
                 student_welfare_assurance_amt = gateway_net_amt(
                     academic_session.welfare_fee)
+                sports_amt = gateway_net_amt(
+                    academic_session.sports_fee)
+                library_amt = gateway_net_amt(
+                    academic_session.library_fee)
                 xmldict['student_union_bank_id'] = '31'
                 xmldict['student_union_acct'] = '0051005007'
@@ -259,4 +263,8 @@
                 student_welfare_assurance_amt = gateway_net_amt(
                     academic_session.welfare_fee)
+                sports_amt = gateway_net_amt(
+                    academic_session.sports_fee)
+                library_amt = gateway_net_amt(
+                    academic_session.library_fee)
                 xmldict['student_union_bank_id'] = '7'
                 xmldict['student_union_acct'] = '1019763348'
@@ -284,4 +292,6 @@
                 xmldict['student_union_due_amt'] = 100 * student_union_due_amt
                 xmldict['student_welfare_assurance_amt'] = 100 * student_welfare_assurance_amt
+                xmldict['sports_amt'] = 100 * sports_amt
+                xmldict['library_amt'] = 100 * library_amt
                 xmldict['institution_amt'] = 100 * (
                     gateway_net_amt(self.context.amount_auth)
@@ -290,5 +300,7 @@
                     - aaue_share_amt
                     - student_union_due_amt
-                    - student_welfare_assurance_amt)
+                    - student_welfare_assurance_amt
+                    - sports_amt
+                    - library_amt)
                 xmltext = """<payment_item_detail>
 <item_details detail_ref="%(detail_ref)s" college="%(institution_name)s" department="%(department)s" faculty="%(faculty)s">
@@ -299,4 +311,6 @@
 <item_detail item_id="5" item_name="Student Union" item_amt="%(student_union_due_amt)d" bank_id="%(student_union_bank_id)s" acct_num="%(student_union_acct)s" />
 <item_detail item_id="6" item_name="Student Welfare Assurance" item_amt="%(student_welfare_assurance_amt)d" bank_id="123" acct_num="1006407792" />
+<item_detail item_id="7" item_name="Sports Development Fee" item_amt="%(sports_amt)d" bank_id="123" acct_num="1005407792" />
+<item_detail item_id="8" item_name="Library Development Fee" item_amt="%(library_amt)d" bank_id="8" acct_num="2000122995" />
 </item_details>
 </payment_item_detail>""" % xmldict
Index: main/waeup.aaue/trunk/src/waeup/aaue/utils/utils.py
===================================================================
--- main/waeup.aaue/trunk/src/waeup/aaue/utils/utils.py	(revision 15178)
+++ main/waeup.aaue/trunk/src/waeup/aaue/utils/utils.py	(revision 15180)
@@ -65,4 +65,6 @@
         'fac_dep': 'Faculty and Departmental Dues',
         'restitution': 'Restitution Fee',
+        'sports_develop': 'Sports Development Fee',
+        'library_develop': 'Library Development Fee',
         }
 

Index: main/waeup.aaue/trunk/src/waeup/aaue/students/utils.py
===================================================================
--- main/waeup.aaue/trunk/src/waeup/aaue/students/utils.py	(revision 15178)
+++ main/waeup.aaue/trunk/src/waeup/aaue/students/utils.py	(revision 15180)
@@ -432,9 +432,12 @@
             if amount in (0.0, None):
                 return _(u'Amount could not be determined.'), None
-            # Add Student Union Fee , Student Id Card Fee and Welfare Assurance
-            if category in ('schoolfee_incl', 'schoolfee_1') and \
-                student.current_mode != 'ijmbe':
-                amount += gateway_net_amt(academic_session.welfare_fee) + \
-                    gateway_net_amt(academic_session.union_fee)
+            # Add Student Union Fee, Student Id Card Fee, Sports Dev. Fee,
+            # Library Dev. Fee and Welfare Assurance
+            if category in ('schoolfee_incl', 'schoolfee_1'):
+                if student.current_mode != 'ijmbe':
+                    amount += gateway_net_amt(academic_session.welfare_fee) + \
+                        gateway_net_amt(academic_session.union_fee)
+                gateway_net_amt(academic_session.sports_fee)
+                gateway_net_amt(academic_session.library_fee)
                 if student.entry_session == 2016 \
                     and student.entry_mode == 'ug_ft' \